@@ -1,5 +1,5 @@
-require "cheffish"
-require "cheffish/chef_actor_base"
+require_relative "../../cheffish"
+require_relative "../../cheffish/chef_actor_base"
 
 class Chef
   class Resource
@@ -8,8 +8,8 @@ class Chef
 
       # Client attributes
       property :chef_client_name, Cheffish::NAME_REGEX, name_property: true
-      property :admin, Boolean
-      property :validator, Boolean
+      property :admin, [TrueClass, FalseClass]
+      property :validator, [TrueClass, FalseClass]
 
       # Input key
       property :source_key # String or OpenSSL::PKey::*
@@ -18,7 +18,7 @@ class Chef
 
       # Output public key (if so desired)
       property :output_key_path, String
-      property :output_key_format, Symbol, default: :openssh, equal_to: [ :pem, :der, :openssh ]
+      property :output_key_format, Symbol, default: :openssh, equal_to: %i{pem der openssh}
 
       # Proc that runs just before the resource executes.  Called with (resource)
       def before(&block)
