@@ -1,5 +1,5 @@
-require "cheffish"
-require "cheffish/base_resource"
+require_relative "../../cheffish"
+require_relative "../../cheffish/base_resource"
 require "chef/chef_fs/file_pattern"
 require "chef/chef_fs/file_system"
 require "chef/chef_fs/parallelizer"
@@ -25,15 +25,15 @@ class Chef
       # Whether the repo path should contain cookbooks with versioned names,
       # i.e. cookbooks/mysql-1.0.0, cookbooks/mysql-1.2.0, etc.
       # Defaults to true if chef_repo_path is specified, or to Chef::Config.versioned_cookbooks otherwise.
-      property :versioned_cookbooks, Boolean
+      property :versioned_cookbooks, [TrueClass, FalseClass]
 
       # Whether to purge deleted things: if we do not have cookbooks/x locally and we
       # *do* have cookbooks/x remotely, then :upload with purge will delete it.
       # Defaults to false.
-      property :purge, Boolean
+      property :purge, [TrueClass, FalseClass]
 
       # Whether to freeze cookbooks on upload
-      property :freeze_on_upload, Boolean
+      property :freeze_on_upload, [TrueClass, FalseClass]
 
       # `freeze` is an already-existing instance method on Object, so we can't use it or we'll throw
       # a deprecation warning. `freeze` has been renamed to `freeze_on_upload` and this method
@@ -45,13 +45,13 @@ class Chef
         set_or_return(
           :freeze_on_upload,
           arg,
-          :kind_of => Boolean
+          kind_of: [TrueClass, FalseClass]
         )
       end
 
       # If this is true, only new files will be copied.  File contents will not be
       # diffed, so changed files will never be uploaded.
-      property :no_diff, Boolean
+      property :no_diff, [TrueClass, FalseClass]
 
       # Number of parallel threads to list/upload/download with.  Defaults to 10.
       property :concurrency, Integer, default: 10, desired_state: false
@@ -95,6 +95,7 @@ class Chef
           if new_resource.concurrency <= 0
             raise "chef_mirror.concurrency must be above 0!  Was set to #{new_resource.concurrency}"
           end
+
           # Honor concurrency
           Chef::ChefFS::Parallelizer.threads = new_resource.concurrency - 1
 
@@ -103,13 +104,14 @@ class Chef
           if new_resource.path[0] == "/"
             raise "Absolute paths in chef_mirror not yet supported."
           end
+
           # Copy!
           path = Chef::ChefFS::FilePattern.new("/#{new_resource.path}")
           ui = CopyListener.new(self)
           error = Chef::ChefFS::FileSystem.copy_to(path, src_root, dest_root, nil, options, ui, proc { |p| p.path })
 
           if error
-            raise "Errors while copying:#{ui.errors.map { |e| "#{e}\n" }.join('')}"
+            raise "Errors while copying:#{ui.errors.map { |e| "#{e}\n" }.join("")}"
           end
         end
 
@@ -153,25 +155,25 @@ class Chef
 
         def remote_fs
           config = {
-            :chef_server_url => new_resource.chef_server[:chef_server_url],
-            :node_name => new_resource.chef_server[:options][:client_name],
-            :client_key => new_resource.chef_server[:options][:signing_key_filename],
-            :repo_mode => repo_mode,
-            :versioned_cookbooks => Chef::Config.versioned_cookbooks,
+            chef_server_url: new_resource.chef_server[:chef_server_url],
+            node_name: new_resource.chef_server[:options][:client_name],
+            client_key: new_resource.chef_server[:options][:signing_key_filename],
+            repo_mode: repo_mode,
+            versioned_cookbooks: Chef::Config.versioned_cookbooks,
           }
           Chef::ChefFS::FileSystem::ChefServer::ChefServerRootDir.new("remote", config)
         end
 
         def repo_mode
-          new_resource.chef_server[:chef_server_url] =~ /\/organizations\// ? "hosted_everything" : "everything"
+          new_resource.chef_server[:chef_server_url] =~ %r{/organizations/} ? "hosted_everything" : "everything"
         end
 
         def options
           result = {
-            :purge => new_resource.purge,
-            :freeze => new_resource.freeze_on_upload,
-            :diff => new_resource.no_diff,
-            :dry_run => whyrun_mode?,
+            purge: new_resource.purge,
+            freeze: new_resource.freeze_on_upload,
+            diff: new_resource.no_diff,
+            dry_run: whyrun_mode?,
           }
           result[:diff] = !result[:diff]
           result[:repo_mode] = repo_mode
@@ -179,8 +181,7 @@ class Chef
           result
         end
 
-        def load_current_resource
-        end
+        def load_current_resource; end
 
         class CopyListener
           def initialize(mirror)
