@@ -1,5 +1,5 @@
-require "cheffish"
-require "cheffish/base_resource"
+require_relative "../../cheffish"
+require_relative "../../cheffish/base_resource"
 require "chef/run_list/run_list_item"
 require "chef/chef_fs/data_handler/data_handler_base"
 
@@ -45,7 +45,7 @@ class Chef
 
         # Revoke invites and memberships when asked
         invites_to_remove.each do |user|
-          if outstanding_invites.has_key?(user)
+          if outstanding_invites.key?(user)
             converge_by "revoke #{user}'s invitation to organization #{new_resource.organization_name}" do
               rest.delete("#{rest.root_url}/organizations/#{new_resource.organization_name}/association_requests/#{outstanding_invites[user]}")
             end
@@ -61,14 +61,14 @@ class Chef
 
         # Invite and add members when asked
         new_resource.invites.each do |user|
-          if !existing_members.include?(user) && !outstanding_invites.has_key?(user)
+          if !existing_members.include?(user) && !outstanding_invites.key?(user)
             converge_by "invite #{user} to organization #{new_resource.organization_name}" do
               rest.post("#{rest.root_url}/organizations/#{new_resource.organization_name}/association_requests", { "user" => user })
             end
           end
         end
         new_resource.members.each do |user|
-          if !existing_members.include?(user)
+          unless existing_members.include?(user)
             converge_by "Add #{user} to organization #{new_resource.organization_name}" do
               rest.post("#{rest.root_url}/organizations/#{new_resource.organization_name}/users/", { "username" => user })
             end
