@@ -1,4 +1,4 @@
-require "cheffish/base_resource"
+require_relative "../../cheffish/base_resource"
 require "chef_zero"
 
 class Chef
@@ -31,7 +31,7 @@ class Chef
         new_resource.cookbooks_from.each do |path|
           ::Dir.entries(path).each do |name|
             if ::File.directory?(::File.join(path, name)) && name != "." && name != ".."
-              new_resource.berksfile.cookbook name, :path => ::File.join(path, name)
+              new_resource.berksfile.cookbook name, path: ::File.join(path, name)
             end
           end
         end
@@ -41,9 +41,10 @@ class Chef
         # Ridley really really wants a key :/
         if new_resource.chef_server[:options][:signing_key_filename]
           new_resource.berksfile.upload(
-            :server_url => new_resource.chef_server[:chef_server_url],
-            :client_name => new_resource.chef_server[:options][:client_name],
-            :client_key => new_resource.chef_server[:options][:signing_key_filename])
+            server_url: new_resource.chef_server[:chef_server_url],
+            client_name: new_resource.chef_server[:options][:client_name],
+            client_key: new_resource.chef_server[:options][:signing_key_filename]
+          )
         else
           file = Tempfile.new("privatekey")
           begin
@@ -51,9 +52,10 @@ class Chef
             file.close
 
             new_resource.berksfile.upload(
-              :server_url => new_resource.chef_server[:chef_server_url],
-              :client_name => new_resource.chef_server[:options][:client_name] || "me",
-              :client_key => file.path)
+              server_url: new_resource.chef_server[:chef_server_url],
+              client_name: new_resource.chef_server[:options][:client_name] || "me",
+              client_key: file.path
+            )
 
           ensure
             file.close
