@@ -1,5 +1,5 @@
-require "cheffish"
-require "cheffish/chef_actor_base"
+require_relative "../../cheffish"
+require_relative "../../cheffish/chef_actor_base"
 
 class Chef
   class Resource
@@ -9,14 +9,14 @@ class Chef
       # Client attributes
       property :user_name, Cheffish::NAME_REGEX, name_property: true
       property :display_name, String
-      property :admin, Boolean
+      property :admin, [TrueClass, FalseClass]
       property :email, String
       property :external_authentication_uid
-      property :recovery_authentication_enabled, Boolean
+      property :recovery_authentication_enabled, [TrueClass, FalseClass]
       property :password, String # Hmm.  There is no way to idempotentize this.
-      #property :salt  # TODO server doesn't support sending or receiving these, but it's the only way to backup / restore a user
-      #property :hashed_password
-      #property :hash_type
+      # property :salt  # TODO server doesn't support sending or receiving these, but it's the only way to backup / restore a user
+      # property :hashed_password
+      # property :hash_type
 
       # Input key
       property :source_key # String or OpenSSL::PKey::*
@@ -25,7 +25,7 @@ class Chef
 
       # Output public key (if so desired)
       property :output_key_path, String
-      property :output_key_format, [ :pem, :der, :openssh ], default: :openssh
+      property :output_key_format, %i{pem der openssh}, default: :openssh
 
       # Proc that runs just before the resource executes.  Called with (resource)
       def before(&block)
