@@ -1,7 +1,7 @@
 require "openssl/cipher"
-require "cheffish/base_resource"
+require_relative "../../cheffish/base_resource"
 require "openssl"
-require "cheffish/key_formatter"
+require_relative "../../cheffish/key_formatter"
 
 class Chef
   class Resource
@@ -12,7 +12,7 @@ class Chef
       default_action :create
 
       property :path, String, name_property: true
-      property :format, [ :pem, :der, :openssh ], default: :openssh
+      property :format, %i{pem der openssh}, default: :openssh
 
       property :source_key
       property :source_key_path, String
@@ -24,9 +24,10 @@ class Chef
       end
 
       action :create do
-        if !new_source_key
+        unless new_source_key
           raise "No source key specified"
         end
+
         desired_output = encode_public_key(new_source_key)
         if Array(current_resource.action) == [ :delete ] || desired_output != IO.read(new_resource.path)
           converge_by "write #{new_resource.format} public key #{new_resource.path} from #{new_source_key_publicity} key #{new_resource.source_key_path}" do
@@ -57,11 +58,11 @@ class Chef
         def new_source_key
           @new_source_key ||= begin
             if new_resource.source_key.is_a?(String)
-              source_key, source_key_format = Cheffish::KeyFormatter.decode(new_resource.source_key, new_resource.source_key_pass_phrase)
+              source_key, _source_key_format = Cheffish::KeyFormatter.decode(new_resource.source_key, new_resource.source_key_pass_phrase)
             elsif new_resource.source_key
               source_key = new_resource.source_key
             elsif new_resource.source_key_path
-              source_key, source_key_format = Cheffish::KeyFormatter.decode(IO.read(new_resource.source_key_path), new_resource.source_key_pass_phrase, new_resource.source_key_path)
+              source_key, _source_key_format = Cheffish::KeyFormatter.decode(IO.read(new_resource.source_key_path), new_resource.source_key_pass_phrase, new_resource.source_key_path)
             else
               return nil
             end
