@@ -1,5 +1,5 @@
 module Cheffish
-  NAME_REGEX = /^[.\-[:alnum:]_]+$/
+  NAME_REGEX = /^[.\-[:alnum:]_]+$/.freeze
 
   def self.inline_resource(provider, provider_action, *resources, &block)
     BasicChefClient.inline_resource(provider, provider_action, *resources, &block)
@@ -7,10 +7,10 @@ module Cheffish
 
   def self.default_chef_server(config = profiled_config)
     {
-      :chef_server_url => config[:chef_server_url],
-      :options => {
-        :client_name => config[:node_name],
-        :signing_key_filename => config[:client_key],
+      chef_server_url: config[:chef_server_url],
+      options: {
+        client_name: config[:node_name],
+        signing_key_filename: config[:client_key],
       },
     }
   end
@@ -58,10 +58,10 @@ module Cheffish
   end
 
   def self.honor_local_mode(local_mode_default = true, &block)
-    if !Chef::Config.has_key?(:local_mode) && !local_mode_default.nil?
+    if !Chef::Config.key?(:local_mode) && !local_mode_default.nil?
       Chef::Config.local_mode = local_mode_default
     end
-    if Chef::Config.local_mode && !Chef::Config.has_key?(:cookbook_path) && !Chef::Config.has_key?(:chef_repo_path)
+    if Chef::Config.local_mode && !Chef::Config.key?(:cookbook_path) && !Chef::Config.key?(:chef_repo_path)
       Chef::Config.chef_repo_path = Chef::Config.find_chef_repo_path(Dir.pwd)
     end
     begin
@@ -81,7 +81,7 @@ module Cheffish
   end
 
   def self.get_private_key(name, config = profiled_config)
-    key, key_path = get_private_key_with_path(name, config)
+    key, _key_path = get_private_key_with_path(name, config)
     key
   end
 
@@ -98,6 +98,7 @@ module Cheffish
     elsif config[:private_key_paths]
       config[:private_key_paths].each do |private_key_path|
         next unless File.exist?(private_key_path)
+
         Dir.entries(private_key_path).sort.each do |key|
           ext = File.extname(key)
           if key == name || ext == "" || ext == ".pem"
@@ -121,11 +122,11 @@ end
 # Include all recipe objects so require 'cheffish' brings in the whole recipe DSL
 
 require "chef/run_list/run_list_item"
-require "cheffish/basic_chef_client"
-require "cheffish/server_api"
+require_relative "cheffish/basic_chef_client"
+require_relative "cheffish/server_api"
 require "chef/knife"
 require "chef/config_fetcher"
 require "chef/log"
 require "chef/application"
-require "cheffish/recipe_dsl"
-require "cheffish/node_properties"
+require_relative "cheffish/recipe_dsl"
+require_relative "cheffish/node_properties"
