@@ -1,4 +1,4 @@
-require "cheffish/version"
+require_relative "version"
 require "chef/dsl/recipe"
 require "chef/event_dispatch/base"
 require "chef/event_dispatch/dispatcher"
@@ -14,7 +14,7 @@ module Cheffish
     include Chef::DSL::Recipe
 
     def initialize(node = nil, events = nil, **chef_config)
-      if !node
+      unless node
         node = Chef::Node.new
         node.name "basic_chef_client"
         node.automatic[:platform] = "basic_chef_client"
@@ -29,10 +29,9 @@ module Cheffish
         @event_catcher = BasicChefClientEvents.new
         dispatcher = Chef::EventDispatch::Dispatcher.new(@event_catcher)
         case events
-        when nil
         when Array
           events.each { |e| dispatcher.register(e) } if events
-        else
+        when !nil # rubocop: disable Lint/LiteralAsCondition
           dispatcher.register(events)
         end
         @run_context = Chef::RunContext.new(node, {}, dispatcher)
