@@ -1,5 +1,5 @@
-require "cheffish/key_formatter"
-require "cheffish/base_resource"
+require_relative "key_formatter"
+require_relative "base_resource"
 
 module Cheffish
   class ChefActorBase < Cheffish::BaseResource
@@ -19,25 +19,26 @@ module Cheffish
             description = [ "update #{actor_type} #{new_resource.name} at #{actor_path}" ] + differences
             converge_by description do
               result = rest.put("#{actor_path}/#{new_resource.name}", normalize_for_put(new_json))
-              current_public_key, current_public_key_format = Cheffish::KeyFormatter.decode(result["public_key"]) if result["public_key"]
+              current_public_key, _current_public_key_format = Cheffish::KeyFormatter.decode(result["public_key"]) if result["public_key"]
             end
           end
         else
           # Create the actor if it's missing
-          if !new_public_key
+          unless new_public_key
             raise "You must specify a public key to create a #{actor_type}!  Use the private_key resource to create a key, and pass it in with source_key_path."
           end
+
           description = [ "create #{actor_type} #{new_resource.name} at #{actor_path}" ] + differences
           converge_by description do
-            result = rest.post("#{actor_path}", normalize_for_post(new_json))
-            current_public_key, current_public_key_format = Cheffish::KeyFormatter.decode(result["public_key"]) if result["public_key"]
+            result = rest.post((actor_path).to_s, normalize_for_post(new_json))
+            current_public_key, _current_public_key_format = Cheffish::KeyFormatter.decode(result["public_key"]) if result["public_key"]
           end
         end
 
         # Write out the public key
         if new_resource.output_key_path
           # TODO use inline_resource
-          key_content = Cheffish::KeyFormatter.encode(current_public_key, { :format => new_resource.output_key_format })
+          key_content = Cheffish::KeyFormatter.encode(current_public_key, { format: new_resource.output_key_format })
           if !current_resource.output_key_path
             action = "create"
           elsif key_content != IO.read(current_resource.output_key_path)
@@ -76,7 +77,7 @@ module Cheffish
         @new_public_key ||= begin
           if new_resource.source_key
             if new_resource.source_key.is_a?(String)
-              key, key_format = Cheffish::KeyFormatter.decode(new_resource.source_key)
+              key, _key_format = Cheffish::KeyFormatter.decode(new_resource.source_key)
 
               if key.private?
                 key.public_key
@@ -95,7 +96,7 @@ module Cheffish
             else
               source_key_str = IO.read(source_key_path)
             end
-            source_key, source_key_format = Cheffish::KeyFormatter.decode(source_key_str, new_resource.source_key_pass_phrase, source_key_path)
+            source_key, _source_key_format = Cheffish::KeyFormatter.decode(source_key_str, new_resource.source_key_pass_phrase, source_key_path)
             if source_key.private?
               source_key.public_key
             else
