@@ -27,7 +27,7 @@ module Cheffish
         result_configs = []
         configs.each do |config|
           value = config[name]
-          if !value.nil?
+          unless value.nil?
             if value.respond_to?(:keys)
               result_configs << value
             elsif result_configs.size > 0
@@ -57,19 +57,23 @@ module Cheffish
     end
 
     def key?(name)
-      configs.any? { |config| config.has_key?(name) }
+      configs.any? { |config| config.key?(name) }
     end
 
     alias_method :has_key?, :key?
 
     def keys
-      configs.flat_map { |c| c.keys }.uniq
+      configs.flat_map(&:keys).uniq
     end
 
     def values
       keys.map { |key| self[key] }
     end
 
+    def empty?
+      configs.empty?
+    end
+
     def each_pair(&block)
       each(&block)
     end
