@@ -1,29 +1,30 @@
-require "cheffish"
+require_relative "../cheffish"
 
 require "chef/version"
 require "chef_zero/server"
 require "chef/chef_fs/chef_fs_data_store"
 require "chef/chef_fs/config"
-require "cheffish/chef_run_data"
-require "cheffish/chef_run_listener"
+require_relative "chef_run_data"
+require_relative "chef_run_listener"
 require "chef/client"
 require "chef/config"
 require "chef_zero/version"
-require "cheffish/merged_config"
-require "chef/resource/chef_acl"
-require "chef/resource/chef_client"
-require "chef/resource/chef_container"
-require "chef/resource/chef_data_bag"
-require "chef/resource/chef_data_bag_item"
-require "chef/resource/chef_environment"
-require "chef/resource/chef_group"
-require "chef/resource/chef_mirror"
-require "chef/resource/chef_node"
-require "chef/resource/chef_organization"
-require "chef/resource/chef_role"
-require "chef/resource/chef_user"
-require "chef/resource/private_key"
-require "chef/resource/public_key"
+require_relative "merged_config"
+require_relative "../chef/resource/chef_acl"
+require_relative "../chef/resource/chef_client"
+require_relative "../chef/resource/chef_container"
+require_relative "../chef/resource/chef_data_bag"
+require_relative "../chef/resource/chef_data_bag_item"
+require_relative "../chef/resource/chef_environment"
+require_relative "../chef/resource/chef_group"
+require_relative "../chef/resource/chef_mirror"
+require_relative "../chef/resource/chef_node"
+require_relative "../chef/resource/chef_organization"
+require_relative "../chef/resource/chef_role"
+require_relative "../chef/resource/chef_user"
+require_relative "../chef/resource/private_key"
+require_relative "../chef/resource/public_key"
+require "chef/util/path_helper"
 
 class Chef
   module DSL
@@ -41,7 +42,7 @@ class Chef
       end
 
       def with_chef_server(server_url, options = {}, &block)
-        run_context.cheffish.with_chef_server({ :chef_server_url => server_url, :options => options }, &block)
+        run_context.cheffish.with_chef_server({ chef_server_url: server_url, options: options }, &block)
       end
 
       def with_chef_local_server(options, &block)
@@ -51,7 +52,7 @@ class Chef
 
         # Create the data store chef-zero will use
         options[:data_store] ||= begin
-          if !options[:chef_repo_path]
+          unless options[:chef_repo_path]
             raise "chef_repo_path must be specified to with_chef_local_server"
           end
 
@@ -62,7 +63,7 @@ class Chef
             symbol_key = "#{type}_path".to_sym
 
             options[symbol_key] ||= begin
-              if options[:chef_repo_path].kind_of?(String)
+              if options[:chef_repo_path].is_a?(String)
                 Chef::Util::PathHelper.join(options[:chef_repo_path], "#{type}s")
               else
                 options[:chef_repo_path].map { |path| Chef::Util::PathHelper.join(path, "#{type}s") }
@@ -119,24 +120,8 @@ class Chef
   Chef::Client.when_run_starts do |run_status|
     # Pulling on cheffish_run_data makes it initialize right now
     run_status.node.run_state[:chef_config] = config = Cheffish.profiled_config(Chef::Config)
-    run_status.node.run_state[:cheffish] = run_data = Cheffish::ChefRunData.new(config)
+    run_status.node.run_state[:cheffish] = Cheffish::ChefRunData.new(config)
     run_status.events.register(Cheffish::ChefRunListener.new(run_status.node))
   end
 
 end
-
-# Chef 12 moved Chef::Config.path_join to PathHelper.join
-if Chef::VERSION.to_i >= 12
-  require "chef/util/path_helper"
-else
-  require "chef/config"
-  class Chef
-    class Util
-      class PathHelper
-        def self.join(*args)
-          Chef::Config.path_join(*args)
-        end
-      end
-    end
-  end
-end
