@@ -1,10 +1,10 @@
 require "chef_zero/rspec"
 require "chef/server_api"
-require "cheffish/rspec/repository_support"
+require_relative "repository_support"
 require "uri"
-require "cheffish/chef_run"
-require "cheffish/rspec/recipe_run_wrapper"
-require "cheffish/rspec/matchers"
+require_relative "../chef_run"
+require_relative "recipe_run_wrapper"
+require_relative "matchers"
 
 module Cheffish
   module RSpec
@@ -20,7 +20,7 @@ module Cheffish
 
       def when_the_chef_12_server(*args, **options, &block)
         if Gem::Version.new(ChefZero::VERSION) >= Gem::Version.new("3.1")
-          when_the_chef_server(*args, :osc_compat => false, :single_org => false, **options, &block)
+          when_the_chef_server(*args, osc_compat: false, single_org: false, **options, &block)
         end
       end
 
@@ -58,11 +58,11 @@ module Cheffish
         end
 
         def recipe(str = nil, file = nil, line = nil, &recipe)
-          if !recipe
+          unless recipe
             if file && line
-              recipe = proc { eval(str, nil, file, line) }
+              recipe = proc { eval(str, nil, file, line) } # rubocop:disable Security/Eval
             else
-              recipe = proc { eval(str) }
+              recipe = proc { eval(str) } # rubocop:disable Security/Eval
             end
           end
           RecipeRunWrapper.new(chef_config, &recipe)
