@@ -1,4 +1,4 @@
-require 'rspec/matchers'
+require "rspec/matchers"
 
 RSpec::Matchers.define :be_idempotent do
   match do |recipe|
@@ -8,9 +8,9 @@ RSpec::Matchers.define :be_idempotent do
     recipe.up_to_date?
   end
 
-  failure_message {
+  failure_message do
     "#{@recipe} is not idempotent!  Converging it a second time caused updates.\n#{@recipe.output_for_failure_message}"
-  }
+  end
 
   supports_block_expectations
 end
