@@ -1,4 +1,4 @@
-require "cheffish/chef_run"
+require_relative "../chef_run"
 require "forwardable"
 
 module Cheffish
@@ -14,7 +14,7 @@ module Cheffish
       attr_reader :example
 
       def client
-        if !@client
+        unless @client
           super
           example = self.example
 
