@@ -10,7 +10,7 @@ if Gem::Version.new(ChefZero::VERSION) >= Gem::Version.new("3.1")
     #        let(:chef_config) { super().merge(log_level: :debug, stdout: STDOUT, stderr: STDERR, log_location: STDOUT) }
 
     context "Rights attributes" do
-      when_the_chef_server "has a node named x", :osc_compat => false do
+      when_the_chef_server "has a node named x", osc_compat: false do
         node "x", {}
 
         it 'Converging chef_acl "nodes/x" changes nothing' do
@@ -160,7 +160,7 @@ if Gem::Version.new(ChefZero::VERSION) >= Gem::Version.new("3.1")
           it 'Converging chef_acl "nodes/x" with rights [ :read, :create, :update, :delete, :grant ] modifies all rights' do
             expect_recipe do
               chef_acl "nodes/x" do
-                rights [ :create, :read, :update, :delete, :grant ], users: %w{u1 u2}, clients: %w{c1}, groups: %w{g1}
+                rights %i{create read update delete grant}, users: %w{u1 u2}, clients: %w{c1}, groups: %w{g1}
               end
             end.to be_updated
             expect(get("nodes/x/_acl")).to partially_match(
@@ -195,7 +195,7 @@ if Gem::Version.new(ChefZero::VERSION) >= Gem::Version.new("3.1")
         end
       end
 
-      when_the_chef_server "has a node named x with user blarghle in its acl", :osc_compat => false do
+      when_the_chef_server "has a node named x with user blarghle in its acl", osc_compat: false do
         user "blarghle", {}
         node "x", {} do
           acl "read" => { "actors" => %w{blarghle} }
@@ -211,7 +211,7 @@ if Gem::Version.new(ChefZero::VERSION) >= Gem::Version.new("3.1")
         end
       end
 
-      when_the_chef_server "has a node named x with users foo and bar in all its acls", :osc_compat => false do
+      when_the_chef_server "has a node named x with users foo and bar in all its acls", osc_compat: false do
         user "foo", {}
         user "bar", {}
         node "x", {} do
@@ -229,11 +229,11 @@ if Gem::Version.new(ChefZero::VERSION) >= Gem::Version.new("3.1")
             end
           end.to be_updated
           expect(get("nodes/x/_acl")).to partially_match(
-                           "create" => { "actors" => exclude("foo") },
-                           "read"   => { "actors" => exclude("foo") },
-                           "update" => { "actors" => exclude("foo") },
-                           "delete" => { "actors" => exclude("foo") },
-                           "grant"  => { "actors" => exclude("foo") }
+            "create" => { "actors" => exclude("foo") },
+            "read"   => { "actors" => exclude("foo") },
+            "update" => { "actors" => exclude("foo") },
+            "delete" => { "actors" => exclude("foo") },
+            "grant"  => { "actors" => exclude("foo") }
           )
         end
       end
@@ -241,7 +241,7 @@ if Gem::Version.new(ChefZero::VERSION) >= Gem::Version.new("3.1")
       ::RSpec::Matchers.define_negated_matcher :exclude, :include
 
       context "recursive" do
-        when_the_chef_server "has a nodes container with user blarghle in its acl", :osc_compat => false do
+        when_the_chef_server "has a nodes container with user blarghle in its acl", osc_compat: false do
           user "blarghle", {}
           acl_for "containers/nodes", "read" => { "actors" => %w{blarghle} }
           node "x", {} do
@@ -255,8 +255,7 @@ if Gem::Version.new(ChefZero::VERSION) >= Gem::Version.new("3.1")
                   rights :read, users: %w{blarghle}
                 end
               end.to be_up_to_date
-            end.to not_change { get("containers/nodes/_acl") }.
-               and not_change { get("nodes/x/_acl") }
+            end.to((not_change { get("containers/nodes/_acl") }).and(not_change { get("nodes/x/_acl") }))
           end
 
           RSpec::Matchers.define_negated_matcher :not_change, :change
@@ -269,8 +268,7 @@ if Gem::Version.new(ChefZero::VERSION) >= Gem::Version.new("3.1")
                   recursive :on_change
                 end
               end.to be_up_to_date
-            end.to not_change { get("containers/nodes/_acl") }.
-               and not_change { get("nodes/x/_acl") }
+            end.to((not_change { get("containers/nodes/_acl") }).and(not_change { get("nodes/x/_acl") }))
           end
 
           it 'Converging chef_acl "nodes" with recursive true changes nodes/x\'s acls' do
@@ -320,7 +318,7 @@ if Gem::Version.new(ChefZero::VERSION) >= Gem::Version.new("3.1")
     end
 
     context "ACLs on each type of thing" do
-      when_the_chef_server "has an organization named foo", :osc_compat => false, :single_org => false do
+      when_the_chef_server "has an organization named foo", osc_compat: false, single_org: false do
         organization "foo" do
           user "u", {}
           client "x", {}
@@ -363,7 +361,8 @@ if Gem::Version.new(ChefZero::VERSION) >= Gem::Version.new("3.1")
               end.to be_updated
               %w{clients containers cookbooks data environments groups nodes roles}.each do |type|
                 expect(get("/organizations/foo/#{type}/x/_acl")).to partially_match(
-                                 "read" => { "actors" => %w{u} })
+                  "read" => { "actors" => %w{u} }
+                )
               end
             end
           end
@@ -410,7 +409,8 @@ if Gem::Version.new(ChefZero::VERSION) >= Gem::Version.new("3.1")
               end.to be_updated
               %w{clients containers cookbooks data environments groups nodes roles sandboxes}.each do |type|
                 expect(get("/organizations/foo/#{type}/x/_acl")).to partially_match(
-                                 "read" => { "actors" => %w{u} })
+                  "read" => { "actors" => %w{u} }
+                )
               end
             end
 
@@ -422,7 +422,8 @@ if Gem::Version.new(ChefZero::VERSION) >= Gem::Version.new("3.1")
               end.to be_updated
               %w{clients containers cookbooks data environments groups nodes roles}.each do |type|
                 expect(get("/organizations/foo/#{type}/x/_acl")).to partially_match(
-                                 "read" => { "actors" => %w{u} })
+                  "read" => { "actors" => %w{u} }
+                )
               end
             end
 
@@ -449,7 +450,7 @@ if Gem::Version.new(ChefZero::VERSION) >= Gem::Version.new("3.1")
                 chef_acl "/organizations/foo/cookbooks/x/1.0.0" do
                   rights :read, users: %w{u}
                 end
-              end.to raise_error(/ACLs cannot be set on children of \/organizations\/foo\/cookbooks\/x/)
+              end.to raise_error(%r{ACLs cannot be set on children of /organizations/foo/cookbooks/x})
             end
 
             it "chef_acl '/organizations/foo/cookbooks/*/*' raises an error" do
@@ -458,7 +459,7 @@ if Gem::Version.new(ChefZero::VERSION) >= Gem::Version.new("3.1")
                 chef_acl "/organizations/foo/cookbooks/*/*" do
                   rights :read, users: %w{u}
                 end
-              end.to raise_error(/ACLs cannot be set on children of \/organizations\/foo\/cookbooks\/*/)
+              end.to raise_error(%r{ACLs cannot be set on children of /organizations/foo/cookbooks/*})
             end
 
             it 'chef_acl "/organizations/foo/data/x/y" raises an error' do
@@ -466,7 +467,7 @@ if Gem::Version.new(ChefZero::VERSION) >= Gem::Version.new("3.1")
                 chef_acl "/organizations/foo/data/x/y" do
                   rights :read, users: %w{u}
                 end
-              end.to raise_error(/ACLs cannot be set on children of \/organizations\/foo\/data\/x/)
+              end.to raise_error(%r{ACLs cannot be set on children of /organizations/foo/data/x})
             end
 
             it 'chef_acl "/organizations/foo/data/*/*" raises an error' do
@@ -475,7 +476,7 @@ if Gem::Version.new(ChefZero::VERSION) >= Gem::Version.new("3.1")
                 chef_acl "/organizations/foo/data/*/*" do
                   rights :read, users: %w{u}
                 end
-              end.to raise_error(/ACLs cannot be set on children of \/organizations\/foo\/data\/*/)
+              end.to raise_error(%r{ACLs cannot be set on children of /organizations/foo/data/*})
             end
 
             it 'chef_acl "/organizations/foo" changes the acl' do
@@ -568,7 +569,7 @@ if Gem::Version.new(ChefZero::VERSION) >= Gem::Version.new("3.1")
         end
       end
 
-      when_the_chef_server 'has a user "u" in single org mode', :osc_compat => false do
+      when_the_chef_server 'has a user "u" in single org mode', osc_compat: false do
         user "u", {}
         client "x", {}
         container "x", {}
@@ -611,7 +612,8 @@ if Gem::Version.new(ChefZero::VERSION) >= Gem::Version.new("3.1")
           end.to be_updated
           %w{clients containers cookbooks data environments groups nodes roles sandboxes}.each do |type|
             expect(get("#{type}/x/_acl")).to partially_match(
-                             "read" => { "actors" => %w{u} })
+              "read" => { "actors" => %w{u} }
+            )
           end
         end
 
@@ -623,7 +625,8 @@ if Gem::Version.new(ChefZero::VERSION) >= Gem::Version.new("3.1")
           end.to be_updated
           %w{clients containers cookbooks data environments groups nodes roles}.each do |type|
             expect(get("#{type}/x/_acl")).to partially_match(
-                             "read" => { "actors" => %w{u} })
+              "read" => { "actors" => %w{u} }
+            )
           end
         end
 
@@ -635,7 +638,8 @@ if Gem::Version.new(ChefZero::VERSION) >= Gem::Version.new("3.1")
           end.to be_updated
           %w{admins billing-admins clients users x}.each do |n|
             expect(get("groups/#{n}/_acl")).to partially_match(
-                             "read" => { "actors" => %w{u} })
+              "read" => { "actors" => %w{u} }
+            )
           end
         end
 
@@ -670,7 +674,7 @@ if Gem::Version.new(ChefZero::VERSION) >= Gem::Version.new("3.1")
     end
 
     context "ACLs on each container type" do
-      when_the_chef_server "has an organization named foo", :osc_compat => false, :single_org => false do
+      when_the_chef_server "has an organization named foo", osc_compat: false, single_org: false do
         organization "foo" do
           user "u", {}
           client "x", {}
@@ -715,7 +719,8 @@ if Gem::Version.new(ChefZero::VERSION) >= Gem::Version.new("3.1")
           end.to be_updated
           %w{clients containers cookbooks data environments groups nodes roles sandboxes}.each do |type|
             expect(get("/organizations/foo/containers/#{type}/_acl")).to partially_match(
-                             "read" => { "actors" => %w{u} })
+              "read" => { "actors" => %w{u} }
+            )
           end
         end
 
@@ -738,7 +743,7 @@ if Gem::Version.new(ChefZero::VERSION) >= Gem::Version.new("3.1")
         end
       end
 
-      when_the_chef_server 'has a user "u" in single org mode', :osc_compat => false do
+      when_the_chef_server 'has a user "u" in single org mode', osc_compat: false do
         user "u", {}
         client "x", {}
         container "x", {}
@@ -754,7 +759,7 @@ if Gem::Version.new(ChefZero::VERSION) >= Gem::Version.new("3.1")
         %w{clients containers cookbooks data environments groups nodes roles sandboxes}.each do |type|
           it "chef_acl #{type}' changes the acl" do
             expect_recipe do
-              chef_acl "#{type}" do
+              chef_acl type.to_s do
                 rights :read, users: %w{u}
               end
             end.to be_updated
@@ -770,14 +775,15 @@ if Gem::Version.new(ChefZero::VERSION) >= Gem::Version.new("3.1")
           end.to be_updated
           %w{clients containers cookbooks data environments groups nodes roles sandboxes}.each do |type|
             expect(get("containers/#{type}/_acl")).to partially_match(
-                             "read" => { "actors" => %w{u} })
+              "read" => { "actors" => %w{u} }
+            )
           end
         end
       end
     end
 
     context "remove_rights" do
-      when_the_chef_server 'has a node "x" with "u", "c" and "g" in its acl', :osc_compat => false do
+      when_the_chef_server 'has a node "x" with "u", "c" and "g" in its acl', osc_compat: false do
         user "u", {}
         user "u2", {}
         client "c", {}
@@ -822,7 +828,7 @@ if Gem::Version.new(ChefZero::VERSION) >= Gem::Version.new("3.1")
         it 'chef_acl with remove_rights [ :create, :read ], "u", "c", "g" removes all three' do
           expect_recipe do
             chef_acl "nodes/x" do
-              remove_rights [ :create, :read ], users: %w{u}, clients: %w{c}, groups: %w{g}
+              remove_rights %i{create read}, users: %w{u}, clients: %w{c}, groups: %w{g}
             end
           end.to be_updated
           expect(get("nodes/x/_acl")).to partially_match(
@@ -838,12 +844,12 @@ if Gem::Version.new(ChefZero::VERSION) >= Gem::Version.new("3.1")
                 remove_rights :read, users: %w{u2}, clients: %w{c2}, groups: %w{g2}
               end
             end.to be_up_to_date
-          end.not_to change { get("nodes/x/_acl") }
+          end.not_to(change { get("nodes/x/_acl") })
         end
       end
     end
 
-    when_the_chef_server "has a node named data_bags", :osc_compat => false do
+    when_the_chef_server "has a node named data_bags", osc_compat: false do
       user "blarghle", {}
       node "data_bags", {}
 
@@ -857,7 +863,7 @@ if Gem::Version.new(ChefZero::VERSION) >= Gem::Version.new("3.1")
       end
     end
 
-    when_the_chef_server "has a node named data_bags in multi-org mode", :osc_compat => false, :single_org => false do
+    when_the_chef_server "has a node named data_bags in multi-org mode", osc_compat: false, single_org: false do
       user "blarghle", {}
       organization "foo" do
         node "data_bags", {}
@@ -873,7 +879,7 @@ if Gem::Version.new(ChefZero::VERSION) >= Gem::Version.new("3.1")
       end
     end
 
-    when_the_chef_server "has a user named data_bags in multi-org mode", :osc_compat => false, :single_org => false do
+    when_the_chef_server "has a user named data_bags in multi-org mode", osc_compat: false, single_org: false do
       user "data_bags", {}
       user "blarghle", {}
 
