@@ -48,7 +48,7 @@ describe Chef::Resource::ChefMirror do
                 action :download
               end
             end
-          end.to raise_error /chef_mirror.concurrency must be above 0/
+          end.to raise_error(/chef_mirror.concurrency must be above 0/)
         end
       end
     end
@@ -158,8 +158,8 @@ describe Chef::Resource::ChefMirror do
           end.to have_updated("chef_mirror[]", :upload)
           expect { get("nodes/x") }.not_to raise_error
           expect { get("roles/x") }.not_to raise_error
-          expect { get("nodes/y") }.to raise_error /404/
-          expect { get("roles/y") }.to raise_error /404/
+          expect { get("nodes/y") }.to raise_error(/404/)
+          expect { get("roles/y") }.to raise_error(/404/)
         end
 
         it "Upload with chef_repo_path(:chef_repo_path) with multiple paths uploads everything" do
@@ -167,7 +167,7 @@ describe Chef::Resource::ChefMirror do
           repo2_path = path_to("repo2")
           expect_recipe do
             chef_mirror "" do
-              chef_repo_path :chef_repo_path => [ repo_path, repo2_path ]
+              chef_repo_path chef_repo_path: [ repo_path, repo2_path ]
               action :upload
             end
           end.to have_updated("chef_mirror[]", :upload)
@@ -183,15 +183,15 @@ describe Chef::Resource::ChefMirror do
 
           expect_recipe do
             chef_mirror "" do
-              chef_repo_path :chef_repo_path => "/blahblah",
-                             :node_path => "#{repo_path}/nodes",
-                             :role_path => "#{repo2_path}/roles"
+              chef_repo_path chef_repo_path: "/blahblah",
+                             node_path: "#{repo_path}/nodes",
+                             role_path: "#{repo2_path}/roles"
               action :upload
             end
           end.to have_updated("chef_mirror[]", :upload)
           expect { get("nodes/x") }.not_to raise_error
-          expect { get("roles/x") }.to raise_error /404/
-          expect { get("nodes/y") }.to raise_error /404/
+          expect { get("roles/x") }.to raise_error(/404/)
+          expect { get("nodes/y") }.to raise_error(/404/)
           expect { get("roles/y") }.not_to raise_error
         end
 
@@ -201,14 +201,14 @@ describe Chef::Resource::ChefMirror do
 
           expect_recipe do
             chef_mirror "" do
-              chef_repo_path :chef_repo_path => repo_path,
-                             :role_path => "#{repo2_path}/roles"
+              chef_repo_path chef_repo_path: repo_path,
+                             role_path: "#{repo2_path}/roles"
               action :upload
             end
           end.to have_updated("chef_mirror[]", :upload)
           expect { get("nodes/x") }.not_to raise_error
-          expect { get("roles/x") }.to raise_error /404/
-          expect { get("nodes/y") }.to raise_error /404/
+          expect { get("roles/x") }.to raise_error(/404/)
+          expect { get("nodes/y") }.to raise_error(/404/)
           expect { get("roles/y") }.not_to raise_error
         end
 
@@ -218,9 +218,9 @@ describe Chef::Resource::ChefMirror do
 
           expect_recipe do
             chef_mirror "" do
-              chef_repo_path :chef_repo_path => %w{foo bar},
-                             :node_path => [ "#{repo_path}/nodes", "#{repo2_path}/nodes" ],
-                             :role_path => [ "#{repo_path}/roles", "#{repo2_path}/roles" ]
+              chef_repo_path chef_repo_path: %w{foo bar},
+                             node_path: [ "#{repo_path}/nodes", "#{repo2_path}/nodes" ],
+                             role_path: [ "#{repo_path}/roles", "#{repo2_path}/roles" ]
               action :upload
             end
           end.to have_updated("chef_mirror[]", :upload)
