@@ -25,7 +25,7 @@ describe Chef::Resource::ChefNode do
 
       context "and another chef server is running on port 8899" do
         before :each do
-          @server = ChefZero::Server.new(:port => 8899)
+          @server = ChefZero::Server.new(port: 8899)
           @server.start_background
         end
 
@@ -50,7 +50,7 @@ describe Chef::Resource::ChefNode do
           it "the node is created on the second chef server but not the first" do
             expect_recipe do
               chef_node "blah" do
-                chef_server({ :chef_server_url => "http://127.0.0.1:8899" })
+                chef_server({ chef_server_url: "http://127.0.0.1:8899" })
               end
             end.to have_updated "chef_node[blah]", :create
             expect { get("nodes/blah") }.to raise_error(Net::HTTPServerException)
@@ -104,11 +104,11 @@ describe Chef::Resource::ChefNode do
       context 'when the Chef server has a node named "blah" with everything in it' do
         node "blah", {
           "chef_environment" => "blah",
-          "run_list"  => [ "recipe[bjork]" ],
-          "normal"    => { "foo" => "bar", "tags" => %w{a b} },
-          "default"   => { "foo2" => "bar2" },
+          "run_list" => [ "recipe[bjork]" ],
+          "normal" => { "foo" => "bar", "tags" => %w{a b} },
+          "default" => { "foo2" => "bar2" },
           "automatic" => { "foo3" => "bar3" },
-          "override"  => { "foo4" => "bar4" },
+          "override" => { "foo4" => "bar4" },
         }
 
         it "chef_node with no attributes modifies nothing" do
@@ -394,7 +394,7 @@ describe Chef::Resource::ChefNode do
                   attribute %w{a b}, "x"
                 end
               end
-            end.to raise_error /Attempt to set \["a", "b"\] to x when \["a"\] is not a hash/
+            end.to raise_error(/Attempt to set \["a", "b"\] to x when \["a"\] is not a hash/)
           end
 
           it "chef_node with attribute [ a, b, c ], x raises an error" do
@@ -404,7 +404,7 @@ describe Chef::Resource::ChefNode do
                   attribute %w{a b c}, "x"
                 end
               end
-            end.to raise_error /Attempt to set \["a", "b", "c"\] to x when \["a"\] is not a hash/
+            end.to raise_error(/Attempt to set \["a", "b", "c"\] to x when \["a"\] is not a hash/)
           end
 
           it "chef_node with attribute [ x, y ], z adds a new attribute" do
