@@ -3,7 +3,7 @@ require "cheffish/rspec"
 require "cheffish"
 
 RSpec.configure do |config|
-  config.filter_run :focus => true
+  config.filter_run focus: true
   config.run_all_when_everything_filtered = true
 
   config.before :each do
